@@ -1,6 +1,6 @@
 from .deep_image_prior import DeepImagePrior
 from .diffusion import BruteDiffusion, PseudoLinearSampler
+from .raw import Raw
 from .jpeg import JPEG
 from .rudalle import BruteRuDalle
-from .pixel import Pixel
 from .stylegan_xl import StyleGANXL
